function [mX]=L1median(X,tol)
 
 % L1MEDIAN calculates the multivariate L1 median  
 % I/O: [mX]=L1median(X,tol); 
 % 
 % X is the data matrix  
 % tol is the convergence criterium; the iterative proces stops when ||m_k - m_{k+1}|| < tol. 
 % 
 % Ref: Hossjer and Croux (1995) "Generalizing Univariate Signed Rank Statistics for Testing 
 % and Estimating a Multivariate Location Parameter", Non-parametric Statistics, 4, 293-308. 
 % Translated from the Gauss code of Hossjer and Croux (1995) in matlab by Sabine Verboven, Antwerp University.  
 
 
% Script downloaded from  
 % http://www.econ.kuleuven.be/public/NDBAE06/programs/#pca 
 
 
 if nargin <2 
    tol=1.e-09; 
 end; 
 [n,p]=size(X); 
 maxstep=1000; 
 %initializing starting value for m 
 m=median(X); 
 k=1; 
 while (k<=maxstep) 
    mold=m; 
    Xext=sortrows([norme(X-repmat(m,n,1)) X],1); 
    dx=Xext(:,1); 
   X=Xext(:,2:p+1); 
    if all(dx) 
      w=1./dx; 
    else 
       ww=dx(all(dx,2)); 
       w=1./ww; 
      w=[zeros(length(dx)-length(w),1);w]; 
    end     
delta=sum((X-repmat(m,n,1)).*repmat(w,1,p),1)./sum(w); 
   nd=norme(delta); 
    if all(nd<tol) 
       maxhalf=0; 
    else 
       maxhalf=log2(nd/tol); 
    end 
 	m=mold+delta;   %computation of a new estimate 
    nstep=0; 
    while all(mrobj(X,m)>=mrobj(X,mold))&&(nstep<=maxhalf) 
       nstep=nstep+1; 
      m=mold+delta./(2^nstep); 
    end 
    if (nstep>maxhalf) 
       mX=mold; 
       break 
    end 
    k=k+1; 
end 
 if k>maxstep 
   display('Iteration failed') 
 end 
mX=m; 


